@@ -20,7 +20,7 @@ from collections import defaultdict
 from contextlib import contextmanager
 from copy import deepcopy
 from functools import partial
-from types import FunctionType, MethodType
+from types import FunctionType, MethodType, BuiltinFunctionType
 
 from . import mix_types as t, _compat as _
 from .factory import GenFactory
@@ -35,15 +35,6 @@ if not LOGGER.handlers and not LOGGER.root.handlers:
     LOGGER.addHandler(logging.StreamHandler())
 
 
-class _Deffered(object):
-
-    """ A type which will be generated later. """
-
-    def __init__(self, value, scheme=None):
-        self.value = value
-        self.scheme = scheme
-
-
 class TypeMixerMeta(type):
 
     """ Cache typemixers by scheme. """
@@ -135,7 +126,7 @@ class TypeMixer(_.with_metaclass(TypeMixerMeta)):
         values = list()
         postprocess_values = list()
         for name, value in candidates:
-            if isinstance(value, _Deffered):
+            if isinstance(value, t._Deffered):
                 postprocess_values.append((name, value))
             else:
                 values.append((name, value))
@@ -177,7 +168,7 @@ class TypeMixer(_.with_metaclass(TypeMixerMeta)):
         if isinstance(value, GeneratorType):
             return self.get_value(name, next(value))
 
-        if isinstance(value, (FunctionType, MethodType)):
+        if isinstance(value, (FunctionType, MethodType, BuiltinFunctionType)):
             return self.get_value(name, value())
 
         return name, value
@@ -241,16 +232,17 @@ class TypeMixer(_.with_metaclass(TypeMixerMeta)):
 
         """
         fake = self.__fake if fake is None else fake
-        if field:
-            fab = self.get_fabric(field, field_name, fake=fake)
-        else:
-            fab = self.__factory.get_fabric(type(field))()
+        if not field:
+            field = t.Field(getattr(self.__scheme, field_name, None), field_name)
+
+        fab = self.get_fabric(field, field_name, fake=fake)
 
         try:
             value = fab()
         except ValueError:
             value = None
         except Exception as exc:
+            LOGGER.exception(exc)
             raise ValueError("Generation for %s (%s) has been stopped. Exception: %s" % (
                 field_name, self.__scheme.__name__, exc))
 
@@ -483,7 +475,7 @@ class Mixer(_.with_metaclass(_MetaMixer)):
         self.params = params
         self.faker = faker
         self.__init_params__(fake=fake, loglevel=loglevel, silence=silence, locale=locale)
-        self.__factory = factory
+        self.__factory = factory or self.type_mixer_cls.factory
 
     def __getattr__(self, name):
         if name in ['f', 'g', 'fake', 'random', 'mix', 'select']:
@@ -542,10 +534,11 @@ class Mixer(_.with_metaclass(_MetaMixer)):
         """
         return self.__class__.MIX
 
-    def __init_params__(self, **params):
+    def __init_params__(self, locale=None, **params):
         self.params.update(params)
-        if self.params.get('locale', faker.locale) != faker.locale:
-            faker.locale = self.params.get('locale')
+        if locale:
+            faker.locale = locale
+            self.params['locale'] = faker.locale
         LOGGER.setLevel(self.params.get('loglevel'))
 
     def __repr__(self):
@@ -563,10 +556,10 @@ class Mixer(_.with_metaclass(_MetaMixer)):
 
             mixer = Mixer()
 
-            mixer.blend(SomeSheme, active=True)
+            mixer.blend(SomeScheme, active=True)
             print scheme.active  # True
 
-            mixer.blend('module.SomeSheme', active=True)
+            mixer.blend('module.SomeScheme', active=True)
             print scheme.active  # True
 
         """
@@ -714,9 +707,18 @@ class Mixer(_.with_metaclass(_MetaMixer)):
 
         def wrapper(middleware):
             type_mixer.middlewares.append(middleware)
+            return middleware
 
         return wrapper
 
+    def unregister_middleware(self, scheme, middleware):
+        """Remove middleware from scheme
+        """
+        type_mixer = self.type_mixer_cls(
+            scheme, mixer=self, fake=self.params.get('fake'),
+            factory=self.__factory)
+        type_mixer.middlewares.remove(middleware)
+
     def register(self, scheme, **params):
         """ Manualy register a function as value's generator for class.field.
 
@@ -766,7 +768,9 @@ class Mixer(_.with_metaclass(_MetaMixer)):
                 self.assertFalse(Hole.objects.count())
 
         """
-        _params = deepcopy(self.params)
+        _params = dict((k, v) for k, v in self.params.items() if k in params)
+        _params['locale'] = self.faker.locale
+
         try:
             self.__init_params__(**params)
             yield self
